@@ -26,28 +26,16 @@ from traceback import format_exc
 
 import numpy as np
 
-from ..base import is_regressor
-from ..utils import Bunch
-from ..utils._param_validation import HasMethods, Hidden, StrOptions, validate_params
-from ..utils._response import _get_response_values
-from ..utils.metadata_routing import (
-    MetadataRequest,
-    MetadataRouter,
-    MethodMapping,
-    _MetadataRequester,
-    _raise_for_params,
-    _routing_enabled,
-    get_routing_for_object,
-    process_routing,
-)
-from ..utils.validation import _check_response_method
-from . import (
+from sklearn.base import is_regressor
+from sklearn.metrics import (
     accuracy_score,
     average_precision_score,
     balanced_accuracy_score,
     brier_score_loss,
     class_likelihood_ratios,
     d2_absolute_error_score,
+    d2_brier_score,
+    d2_log_loss_score,
     explained_variance_score,
     f1_score,
     jaccard_score,
@@ -69,7 +57,7 @@ from . import (
     root_mean_squared_log_error,
     top_k_accuracy_score,
 )
-from .cluster import (
+from sklearn.metrics.cluster import (
     adjusted_mutual_info_score,
     adjusted_rand_score,
     completeness_score,
@@ -80,6 +68,24 @@ from .cluster import (
     rand_score,
     v_measure_score,
 )
+from sklearn.utils import Bunch
+from sklearn.utils._param_validation import (
+    HasMethods,
+    StrOptions,
+    validate_params,
+)
+from sklearn.utils._response import _get_response_values
+from sklearn.utils.metadata_routing import (
+    MetadataRequest,
+    MetadataRouter,
+    MethodMapping,
+    _MetadataRequester,
+    _raise_for_params,
+    _routing_enabled,
+    get_routing_for_object,
+    process_routing,
+)
+from sklearn.utils.validation import _check_response_method
 
 
 def _cached_call(cache, estimator, response_method, *args, **kwargs):
@@ -97,6 +103,14 @@ def _cached_call(cache, estimator, response_method, *args, **kwargs):
     return result
 
 
+def _get_func_repr_or_name(func):
+    """Returns the name of the function or repr of a partial."""
+    if isinstance(func, partial):
+        return repr(func)
+
+    return func.__name__
+
+
 class _MultimetricScorer:
     """Callable for multimetric scoring used to avoid repeated calls
     to `predict_proba`, `predict`, and `decision_function`.
@@ -129,10 +143,22 @@ class _MultimetricScorer:
         if _routing_enabled():
             routed_params = process_routing(self, "score", **kwargs)
         else:
-            # they all get the same args, and they all get them all
+            # Scorers all get the same args, and get all of them except sample_weight.
+            # Only the ones having `sample_weight` in their signature will receive it.
+            # This does not work for metadata other than sample_weight, and for those
+            # users have to enable metadata routing.
+            common_kwargs = {
+                arg: value for arg, value in kwargs.items() if arg != "sample_weight"
+            }
             routed_params = Bunch(
-                **{name: Bunch(score=kwargs) for name in self._scorers}
+                **{name: Bunch(score=common_kwargs.copy()) for name in self._scorers}
             )
+            if "sample_weight" in kwargs:
+                for name, scorer in self._scorers.items():
+                    if scorer._accept_sample_weight():
+                        routed_params[name].score["sample_weight"] = kwargs[
+                            "sample_weight"
+                        ]
 
         for name, scorer in self._scorers.items():
             try:
@@ -154,6 +180,10 @@ class _MultimetricScorer:
         scorers = ", ".join([f'"{s}"' for s in self._scorers])
         return f"MultiMetricScorer({scorers})"
 
+    def _accept_sample_weight(self):
+        # TODO(slep006): remove when metadata routing is the only way
+        return any(scorer._accept_sample_weight() for scorer in self._scorers.values())
+
     def _use_cache(self, estimator):
         """Return True if using a cache is beneficial, thus when a response method will
         be called several time.
@@ -189,7 +219,7 @@ class _MultimetricScorer:
             A :class:`~utils.metadata_routing.MetadataRouter` encapsulating
             routing information.
         """
-        return MetadataRouter(owner=self.__class__.__name__).add(
+        return MetadataRouter(owner=self).add(
             **self._scorers,
             method_mapping=MethodMapping().add(caller="score", callee="score"),
         )
@@ -220,8 +250,6 @@ class _BaseScorer(_MetadataRequester):
         self._sign = sign
         self._kwargs = kwargs
         self._response_method = response_method
-        # TODO (1.8): remove in 1.8 (scoring="max_error" has been deprecated in 1.6)
-        self._deprecation_msg = None
 
     def _get_pos_label(self):
         if "pos_label" in self._kwargs:
@@ -231,16 +259,23 @@ class _BaseScorer(_MetadataRequester):
             return score_func_params["pos_label"].default
         return None
 
+    def _accept_sample_weight(self):
+        # TODO(slep006): remove when metadata routing is the only way
+        return "sample_weight" in signature(self._score_func).parameters
+
     def __repr__(self):
         sign_string = "" if self._sign > 0 else ", greater_is_better=False"
         response_method_string = f", response_method={self._response_method!r}"
         kwargs_string = "".join([f", {k}={v}" for k, v in self._kwargs.items()])
 
         return (
-            f"make_scorer({self._score_func.__name__}{sign_string}"
+            f"make_scorer({_get_func_repr_or_name(self._score_func)}{sign_string}"
             f"{response_method_string}{kwargs_string})"
         )
 
+    def _routing_repr(self):
+        return repr(self)
+
     def __call__(self, estimator, X, y_true, sample_weight=None, **kwargs):
         """Evaluate predicted target values for X relative to y_true.
 
@@ -273,12 +308,6 @@ class _BaseScorer(_MetadataRequester):
         score : float
             Score function applied to prediction of estimator on X.
         """
-        # TODO (1.8): remove in 1.8 (scoring="max_error" has been deprecated in 1.6)
-        if self._deprecation_msg is not None:
-            warnings.warn(
-                self._deprecation_msg, category=DeprecationWarning, stacklevel=2
-            )
-
         _raise_for_params(kwargs, self, None)
 
         _kwargs = copy.deepcopy(kwargs)
@@ -330,7 +359,7 @@ class _BaseScorer(_MetadataRequester):
             ),
             kwargs=kwargs,
         )
-        self._metadata_request = MetadataRequest(owner=self.__class__.__name__)
+        self._metadata_request = MetadataRequest(owner=self)
         for param, alias in kwargs.items():
             self._metadata_request.score.add_request(param=param, alias=alias)
         return self
@@ -432,12 +461,7 @@ def get_scorer(scoring):
     """
     if isinstance(scoring, str):
         try:
-            if scoring == "max_error":
-                # TODO (1.8): scoring="max_error" has been deprecated in 1.6,
-                # remove in 1.8
-                scorer = max_error_scorer
-            else:
-                scorer = copy.deepcopy(_SCORERS[scoring])
+            scorer = copy.deepcopy(_SCORERS[scoring])
         except KeyError:
             raise ValueError(
                 "%r is not a valid scoring value. "
@@ -456,23 +480,19 @@ class _PassthroughScorer(_MetadataRequester):
     def __init__(self, estimator):
         self._estimator = estimator
 
-        requests = MetadataRequest(owner=self.__class__.__name__)
-        try:
-            requests.score = copy.deepcopy(estimator._metadata_request.score)
-        except AttributeError:
-            try:
-                requests.score = copy.deepcopy(estimator._get_default_requests().score)
-            except AttributeError:
-                pass
-
-        self._metadata_request = requests
-
     def __call__(self, estimator, *args, **kwargs):
         """Method that wraps estimator.score"""
         return estimator.score(*args, **kwargs)
 
     def __repr__(self):
-        return f"{self._estimator.__class__}.score"
+        return f"{type(self._estimator).__name__}.score"
+
+    def _routing_repr(self):
+        return repr(self)
+
+    def _accept_sample_weight(self):
+        # TODO(slep006): remove when metadata routing is the only way
+        return "sample_weight" in signature(self._estimator.score).parameters
 
     def get_metadata_routing(self):
         """Get requested data properties.
@@ -488,32 +508,7 @@ class _PassthroughScorer(_MetadataRequester):
             A :class:`~utils.metadata_routing.MetadataRouter` encapsulating
             routing information.
         """
-        return get_routing_for_object(self._metadata_request)
-
-    def set_score_request(self, **kwargs):
-        """Set requested parameters by the scorer.
-
-        Please see :ref:`User Guide <metadata_routing>` on how the routing
-        mechanism works.
-
-        .. versionadded:: 1.5
-
-        Parameters
-        ----------
-        kwargs : dict
-            Arguments should be of the form ``param_name=alias``, and `alias`
-            can be one of ``{True, False, None, str}``.
-        """
-        if not _routing_enabled():
-            raise RuntimeError(
-                "This method is only available when metadata routing is enabled."
-                " You can enable it using"
-                " sklearn.set_config(enable_metadata_routing=True)."
-            )
-
-        for param, alias in kwargs.items():
-            self._metadata_request.score.add_request(param=param, alias=alias)
-        return self
+        return get_routing_for_object(self._estimator)
 
 
 def _check_multimetric_scoring(estimator, scoring):
@@ -616,18 +611,16 @@ def _get_response_method_name(response_method):
     {
         "score_func": [callable],
         "response_method": [
-            None,
             list,
             tuple,
             StrOptions({"predict", "predict_proba", "decision_function"}),
-            Hidden(StrOptions({"default"})),
         ],
         "greater_is_better": ["boolean"],
     },
     prefer_skip_nested_validation=True,
 )
 def make_scorer(
-    score_func, *, response_method="default", greater_is_better=True, **kwargs
+    score_func, *, response_method="predict", greater_is_better=True, **kwargs
 ):
     """Make a scorer from a performance metric or loss function.
 
@@ -649,7 +642,7 @@ def make_scorer(
         ``score_func(y, y_pred, **kwargs)``.
 
     response_method : {"predict_proba", "decision_function", "predict"} or \
-            list/tuple of such str, default=None
+            list/tuple of such str, default="predict"
 
         Specifies the response method to use get prediction from an estimator
         (i.e. :term:`predict_proba`, :term:`decision_function` or
@@ -659,14 +652,9 @@ def make_scorer(
         - if a list or tuple of `str`, it provides the method names in order of
           preference. The method returned corresponds to the first method in
           the list and which is implemented by `estimator`.
-        - if `None`, it is equivalent to `"predict"`.
 
         .. versionadded:: 1.4
 
-        .. deprecated:: 1.6
-            None is equivalent to 'predict' and is deprecated. It will be removed in
-            version 1.8.
-
     greater_is_better : bool, default=True
         Whether `score_func` is a score function (default), meaning high is
         good, or a loss function, meaning low is good. In the latter case, the
@@ -693,16 +681,6 @@ def make_scorer(
     """
     sign = 1 if greater_is_better else -1
 
-    if response_method is None:
-        warnings.warn(
-            "response_method=None is deprecated in version 1.6 and will be removed "
-            "in version 1.8. Leave it to its default value to avoid this warning.",
-            FutureWarning,
-        )
-        response_method = "predict"
-    elif response_method == "default":
-        response_method = "predict"
-
     return _Scorer(score_func, sign, kwargs, response_method)
 
 
@@ -710,14 +688,6 @@ def make_scorer(
 explained_variance_scorer = make_scorer(explained_variance_score)
 r2_scorer = make_scorer(r2_score)
 neg_max_error_scorer = make_scorer(max_error, greater_is_better=False)
-max_error_scorer = make_scorer(max_error, greater_is_better=False)
-# TODO (1.8): remove in 1.8 (scoring="max_error" has been deprecated in 1.6)
-deprecation_msg = (
-    "Scoring method max_error was renamed to "
-    "neg_max_error in version 1.6 and will "
-    "be removed in 1.8."
-)
-max_error_scorer._deprecation_msg = deprecation_msg
 neg_mean_squared_error_scorer = make_scorer(mean_squared_error, greater_is_better=False)
 neg_mean_squared_log_error_scorer = make_scorer(
     mean_squared_log_error, greater_is_better=False
@@ -745,6 +715,8 @@ neg_mean_gamma_deviance_scorer = make_scorer(
     mean_gamma_deviance, greater_is_better=False
 )
 d2_absolute_error_scorer = make_scorer(d2_absolute_error_score)
+d2_brier_score_scorer = make_scorer(d2_brier_score, response_method="predict_proba")
+d2_log_loss_scorer = make_scorer(d2_log_loss_score, response_method="predict_proba")
 
 # Standard Classification Scores
 accuracy_scorer = make_scorer(accuracy_score)
@@ -753,11 +725,11 @@ matthews_corrcoef_scorer = make_scorer(matthews_corrcoef)
 
 
 def positive_likelihood_ratio(y_true, y_pred):
-    return class_likelihood_ratios(y_true, y_pred)[0]
+    return class_likelihood_ratios(y_true, y_pred, replace_undefined_by=1.0)[0]
 
 
 def negative_likelihood_ratio(y_true, y_pred):
-    return class_likelihood_ratios(y_true, y_pred)[1]
+    return class_likelihood_ratios(y_true, y_pred, replace_undefined_by=1.0)[1]
 
 
 positive_likelihood_ratio_scorer = make_scorer(positive_likelihood_ratio)
@@ -838,6 +810,8 @@ _SCORERS = dict(
     neg_mean_poisson_deviance=neg_mean_poisson_deviance_scorer,
     neg_mean_gamma_deviance=neg_mean_gamma_deviance_scorer,
     d2_absolute_error_score=d2_absolute_error_scorer,
+    d2_log_loss_score=d2_log_loss_scorer,
+    d2_brier_score=d2_brier_score_scorer,
     accuracy=accuracy_scorer,
     top_k_accuracy=top_k_accuracy_scorer,
     roc_auc=roc_auc_scorer,
@@ -932,8 +906,10 @@ def check_scoring(estimator=None, scoring=None, *, allow_none=False, raise_exc=T
     scoring : str, callable, list, tuple, set, or dict, default=None
         Scorer to use. If `scoring` represents a single score, one can use:
 
-        - a single string (see :ref:`scoring_parameter`);
-        - a callable (see :ref:`scoring_callable`) that returns a single value.
+        - a single string (see :ref:`scoring_string_names`);
+        - a callable (see :ref:`scoring_callable`) that returns a single value;
+        - `None`, the `estimator`'s
+          :ref:`default evaluation criterion <scoring_api_overview>` is used.
 
         If `scoring` represents multiple scores, one can use:
 
@@ -943,8 +919,6 @@ def check_scoring(estimator=None, scoring=None, *, allow_none=False, raise_exc=T
         - a dictionary with metric names as keys and callables a values. The callables
           need to have the signature `callable(estimator, X, y)`.
 
-        If None, the provided estimator object's `score` method is used.
-
     allow_none : bool, default=False
         Whether to return None or raise an error if no `scoring` is specified and the
         estimator has no `score` method.
